# Name: gcp_poc_setup.ps1
# Purpose: Automate deployment of Velostrata GCP IAM Service Account
# Created: 14/12/2017
# Modified: 08/05/2018
# Author: Alon Pildus
# Created For: velostrata.com
# Version: 1.1

# Create GCP Deployment
# Create GCP Velostrata IAM Service Accounts
# Create GCP Velostrata IAM Custom Roles for MGMT and CE Operations

write-host ("`nVelostrata-GCP IAM Service Accounts Script") -foreground "Green"


################## Login and Subscription ###################

# Sign-in with GCP Account Credentials

$GCPAccount = Read-Host "`nEnter an administrative Google Account - JDOE@GMAIL.COM"

$GCPProject = Read-Host "`nEnter an existing GCP PROJECT ID, Project will be used for the Velostrata PoC"

gcloud auth login $GCPAccount --no-launch-browser --brief

gcloud config set project $GCPProject

################## Environment Variables ###################

$IAMName = (Read-Host "`nEnter a prefix that would be assigned to the IAM Service Accounts about to be created (Lowercase, Minimum Length - 8 characters)").ToLower()
$IAMName_ForRoleId = $IAMName.Replace("-","_")

$VerbosePreference = "continue"

Write-Host

Write-Host "Creating the GCP Velostrata IAM Service Accounts and Roles" $IAMName -foreground "cyan"

Write-Host

(Get-Content ./templates/gcp_poc_iam_only_setup_v1.0.jinja).replace('[MGMT_ROLE_ID_PREFIX]', $IAMName_ForRoleId) | Set-Content ./templates/gcp_poc_iam_only_setup_v1.0_m.jinja
gcloud deployment-manager deployments create $IAMName --template ./templates/gcp_poc_iam_only_setup_v1.0_m.jinja

$CEServiceAccount = "$IAMName-ce@$GCPProject.iam.gserviceaccount.com"
$MgmtServiceAccount = "$IAMName-mgmt@$GCPProject.iam.gserviceaccount.com"


gcloud projects add-iam-policy-binding $GCPProject --member serviceAccount:$CEServiceAccount --role projects/$GCPProject/roles/$IAMName_ForRoleId"_ce_role"
gcloud projects add-iam-policy-binding $GCPProject --member serviceAccount:$MgmtServiceAccount --role projects/$GCPProject/roles/$IAMName_ForRoleId"_mgmt_role"

(Get-Content ./templates/binding.yaml).replace('[MGMT_SA]', $MgmtServiceAccount) | Set-Content binding_m.yaml
gcloud iam service-accounts set-iam-policy $CEServiceAccount binding_m.yaml

gcloud iam service-accounts keys create $IAMName --iam-account=$MgmtServiceAccount --key-file-type="json"

Write-Host "`nService Account Keys JSON file was created and downloaded " -foregroundcolor "Cyan"

Write-Host